Appendix
========

.. envvar:: XDG_DATA_DIRS

   For information on the usage of ``XDG_DATA_HOME`` and
   ``XDG_DATA_DIRS`` read `XDG Base Directory Specification`_

.. _XDG Base Directory Specification: http://standards.freedesktop.org/basedir-spec/basedir-spec-latest.html
